==> haskell-foldl-1.2.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.2.3
id: foldl-1.2.3-24gjzmBTNPhJotPX6quS0n
key: foldl-1.2.3-24gjzmBTNPhJotPX6quS0n
license: BSD3
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
hidden-modules: Control.Foldl.Internal
abi: f1586ca08aca88de3c8684c7dde0e90b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/foldl-1.2.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/foldl-1.2.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/foldl-1.2.3
hs-libraries: HSfoldl-1.2.3-24gjzmBTNPhJotPX6quS0n
depends:
    base-4.9.0.0 bytestring-0.10.8.1 comonad-5-32c0CBnUQitJOjClwXgxTu
    containers-0.5.7.1 contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    profunctors-5.2-5RA339bRfsXIbryi2lNqpM
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.2.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.2.3
id: foldl-1.2.3-79eswbd8l2Q5ZY7g2Wzg7
key: foldl-1.2.3-79eswbd8l2Q5ZY7g2Wzg7
license: BSD3
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
hidden-modules: Control.Foldl.Internal
abi: 69289e31749b253a09e3a9f9a95c411b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/foldl-1.2.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/foldl-1.2.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/foldl-1.2.3
hs-libraries: HSfoldl-1.2.3-79eswbd8l2Q5ZY7g2Wzg7
depends:
    base-4.9.0.0 bytestring-0.10.8.1 comonad-5-FocVP0xchqoELxW0q31ZBF
    containers-0.5.7.1 contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    profunctors-5.2-DDzWnW7PWEeEYRCGSjacrC
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
